#!/bin/sh

# This script is started by scanbuttond whenever a scanner button has been 
# pressed.
#
# Scanbuttond passes the following parameters to us:
# $1 ... the button number
# $2 ... the scanner's SANE device name, which comes in handy if there are two 
#        or more scanners. In this case we can pass the device name to SANE
#        programs like scanimage.
#
# No locking is performed because scanbuttond can not monitor button
# pressing using libusb while sane is scanning.  It also doesn't appear
# to scan for new button presses until this script exits.
# 

EDITBUTTON=1
PRINTBUTTON=2
EMAILBUTTON=3
CUSTOMBUTTON=4

if [ "$1"x = "$EDITBUTTON"x ] ; then
  MODE=Color
  RESOLUTION=300
elif [ "$1"x = "$PRINTBUTTON"x ] ; then
  MODE=Color
  RESOLUTION=150
elif [ "$1"x = "$EMAILBUTTON"x ] ; then 
  MODE=Color
  RESOLUTION=150
else
  MODE=Color
  RESOLUTION=300
fi

TMPFILE="/tmp/scan.pnm"
TMPJPGFILE="/tmp/scan.jpg"

# 8.5 x 11
SCANIMAGE_PAGESIZE="-x 215 -y 279"
# A4
#SCANIMAGE_PAGESIZE="-x 210 -y 297"

scancmd() {
    scanimage --device-name $2 --mode $MODE --resolution $RESOLUTION --depth 8 $SCANIMAGE_PAGESIZE > $TMPFILE
}

editcmd() {
    gimp $TMPFILE
}

printcmd() {
    lpr -o fitplot $TMPFILE
}

mailcmd() {
    convert $TMPFILE -quality 85 -quiet $TMPJPGFILE
    # FIXME: Evolution doesn't seem to put itself in the
    # background after this command is issued; at least
    # if its not already running.  This will cause this
    # script to not exit.  If we just put this into the
    # background then our cleanup() will delete the file
    # before it can be used.
    #evolution mailto:?attach=${TMPJPGFILE}
    thunderbird -compose attachment="file://${TMPJPGFILE}"
}

# function: remove temporary files
cleanup() {
    rm -f $TMPFILE
    if [ -e $TMPJPGFILE ] ; then
        rm -f $TMPJPGFILE
    fi
}

case $1 in
	$EDITBUTTON)
		echo "button $EDITBUTTON has been pressed on $2"

                 scancmd $*
                 editcmd
                 cleanup 
		;;
	$PRINTBUTTON)
		echo "button $PRINTBUTTON has been pressed on $2"

                 scancmd $*
		 printcmd
                 cleanup 
		;;
	$EMAILBUTTON)
		echo "button $EMAILBUTTON has been pressed on $2"

                 scancmd $*
                 mailcmd
                 cleanup
		;;
	$CUSTOMBUTTON)
		echo "button $CUSTOMBUTTON has been pressed on $2"
		;;
esac

